@@ -1,11 +1,15 @@
 package Net::DNS::Header;
+#
+# $Id: Header.pm,v 1.9 2003/06/11 09:56:13 ctriv Exp $
+#
 
 use strict;
 use vars qw($VERSION $AUTOLOAD);
 
 use Net::DNS;
 
-# $Id: Header.pm,v 1.7 2002/08/20 16:27:40 ctriv Exp $
+use constant MAX_ID => 65535;
+
 $VERSION = $Net::DNS::VERSION;
 
 =head1 NAME
@@ -39,6 +43,14 @@ the data is incomplete).
 
 =cut
 
+{
+	my $id = int rand(MAX_ID);
+	
+	sub nextid {
+		return $id++ % (MAX_ID + 1);
+	}
+}
+
 sub new {
 	my $class = shift;
 	my %self;
@@ -70,7 +82,7 @@ sub new {
 	}
 	else { 
 		%self = (
-			"id"		=> Net::DNS::Resolver::nextid(),
+			"id"		=> nextid(),
 			"qr"		=> 0,
 			"opcode"	=> 0,
 			"aa"		=> 0,
@@ -109,10 +121,7 @@ Dumps the header data to the standard output.
 
 =cut
 
-sub print {
-	my $self = shift;
-	print $self->string;
-}
+sub print {	print $_[0]->string; }
 
 =head2 string
 
@@ -283,10 +292,12 @@ sub AUTOLOAD {
 	goto &{$AUTOLOAD};	
 }
 
-sub zocount { my $self = shift; $self->qdcount(@_); }
-sub prcount { my $self = shift; $self->ancount(@_); }
-sub upcount { my $self = shift; $self->nscount(@_); }
-sub adcount { my $self = shift; $self->arcount(@_); }
+sub zocount { &qdcount; }
+sub prcount { &ancount; }
+sub upcount { &nscount; }
+sub adcount { &arcount; }
+
+
 
 =head2 data
 
@@ -310,7 +321,7 @@ sub data {
 	          | $self->{"rd"};
 
 	my $byte3 = ($self->{"ra"} << 7)
-                  | ($self->{"cd"} << 4)
+	          | ($self->{"cd"} << 4)
 	          | $rcode;
 
 	return pack("n C2 n4", $self->{"id"},
